@@ -34,22 +34,32 @@
 #include <QtGui/QPainter>
 #include <QtGui/QTextDocument>
 
-using namespace Akonadi;
+namespace Akonadi {
+namespace Internal {
+
+static void iconsEarlyCleanup();
 
 struct Icons
 {
   Icons()
-   : readyPixmap( KIcon( QLatin1String("user-online") ).pixmap( QSize( 16, 16 ) ) )
-   , syncPixmap( KIcon( QLatin1String("network-connect") ).pixmap( QSize( 16, 16 ) ) )
-   , errorPixmap( KIcon( QLatin1String("dialog-error") ).pixmap( QSize( 16, 16 ) ) )
-   , offlinePixmap( KIcon( QLatin1String("network-disconnect") ).pixmap( QSize( 16, 16 ) ) )
+   : readyPixmap( KIcon( QLatin1String( "user-online" ) ).pixmap( QSize( 16, 16 ) ) )
+   , syncPixmap( KIcon( QLatin1String( "network-connect" ) ).pixmap( QSize( 16, 16 ) ) )
+   , errorPixmap( KIcon( QLatin1String( "dialog-error" ) ).pixmap( QSize( 16, 16 ) ) )
+   , offlinePixmap( KIcon( QLatin1String( "network-disconnect" ) ).pixmap( QSize( 16, 16 ) ) )
   {
+    qAddPostRoutine( iconsEarlyCleanup );
   }
   QPixmap readyPixmap, syncPixmap, errorPixmap, offlinePixmap;
 };
 
 K_GLOBAL_STATIC( Icons, s_icons )
 
+// called as a Qt post routine, to prevent pixmap leaking
+void iconsEarlyCleanup() {
+  Icons * const ic = s_icons;
+  ic->readyPixmap = ic->syncPixmap = ic->errorPixmap = ic->offlinePixmap = QPixmap();
+}
+
 /**
  * @internal
  */
@@ -67,6 +77,10 @@ class AgentInstanceWidgetDelegate : public QAbstractItemDelegate
     QTextDocument* document( const QStyleOptionViewItem &option, const QModelIndex &index ) const;
 };
 
+}
+
+using Akonadi::Internal::AgentInstanceWidgetDelegate;
+
 /**
  * @internal
  */
@@ -114,10 +128,13 @@ AgentInstanceWidget::AgentInstanceWidget( QWidget *parent )
 {
   QHBoxLayout *layout = new QHBoxLayout( this );
   layout->setMargin( 0 );
-  layout->setSpacing( 0 );
 
   d->mView = new QListView( this );
-  d->mView->setItemDelegate( new AgentInstanceWidgetDelegate( d->mView ) );
+  d->mView->setContextMenuPolicy( Qt::NoContextMenu );
+  d->mView->setItemDelegate( new Internal::AgentInstanceWidgetDelegate( d->mView ) );
+  d->mView->setVerticalScrollMode( QAbstractItemView::ScrollPerPixel );
+  d->mView->setAlternatingRowColors( true );
+  d->mView->setSelectionMode( QAbstractItemView::ExtendedSelection );
   layout->addWidget( d->mView );
 
   d->mModel = new AgentInstanceModel( this );
@@ -129,10 +146,10 @@ AgentInstanceWidget::AgentInstanceWidget( QWidget *parent )
   d->mView->selectionModel()->setCurrentIndex( d->mView->model()->index( 0, 0 ), QItemSelectionModel::Select );
   d->mView->scrollTo( d->mView->model()->index( 0, 0 ) );
 
-  connect( d->mView->selectionModel(), SIGNAL( currentChanged( const QModelIndex&, const QModelIndex& ) ),
-           this, SLOT( currentAgentInstanceChanged( const QModelIndex&, const QModelIndex& ) ) );
-  connect( d->mView, SIGNAL( doubleClicked( const QModelIndex& ) ),
-           this, SLOT( currentAgentInstanceDoubleClicked( const QModelIndex& ) ) );
+  connect( d->mView->selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)),
+           this, SLOT(currentAgentInstanceChanged(QModelIndex,QModelIndex)) );
+  connect( d->mView, SIGNAL(doubleClicked(QModelIndex)),
+           this, SLOT(currentAgentInstanceDoubleClicked(QModelIndex)) );
 }
 
 AgentInstanceWidget::~AgentInstanceWidget()
@@ -153,6 +170,29 @@ AgentInstance AgentInstanceWidget::currentAgentInstance() const
   return index.data( AgentInstanceModel::InstanceRole ).value<AgentInstance>();
 }
 
+QList<AgentInstance> AgentInstanceWidget::selectedAgentInstances() const
+{
+  QList<AgentInstance> list;
+  QItemSelectionModel *selectionModel = d->mView->selectionModel();
+  if ( !selectionModel )
+    return list;
+
+  const QModelIndexList indexes = selectionModel->selection().indexes();
+
+  foreach (const QModelIndex &index, indexes )
+  {
+    list.append( index.data( AgentInstanceModel::InstanceRole ).value<AgentInstance>() );
+  }
+
+  return list;
+}
+
+QAbstractItemView* AgentInstanceWidget::view() const
+{
+  return d->mView;
+}
+
+
 AgentFilterProxyModel* AgentInstanceWidget::agentFilterProxyModel() const
 {
   return d->proxy;
@@ -212,16 +252,14 @@ QTextDocument* AgentInstanceWidgetDelegate::document( const QStyleOptionViewItem
      "<body>"
      "<table>"
      "<tr>"
-     "<td rowspan=\"2\"><img src=\"agent_icon\"></td>"
+     "<td rowspan=\"2\"><img src=\"agent_icon\">&nbsp;&nbsp;</td>"
      "<td><b>%2</b></td>"
-     "</tr>" ).arg(textColor.name().toUpper()).arg( name );
-  if ( capabilities.contains( QLatin1String( "Resource" ) ) ) {
-     content += QString::fromLatin1(
+     "</tr>" ).arg(textColor.name().toUpper()).arg( name )
+     + QString::fromLatin1(
      "<tr>"
      "<td><img src=\"status_icon\"/> %1 %2</td>"
-     "</tr>" ).arg( statusMessage ).arg( status == 1 ? QString( QLatin1String( "(%1%)" ) ).arg( progress ) : QLatin1String( "" ) );
-  }
-  content += QLatin1String( "</table></body></html>" );
+     "</tr>" ).arg( statusMessage ).arg( status == 1 ? QString( QLatin1String( "(%1%)" ) ).arg( progress ) : QLatin1String( "" ) )
+     + QLatin1String( "</table></body></html>" );
 
   document->setHtml( content );
 
@@ -245,12 +283,9 @@ void AgentInstanceWidgetDelegate::paint( QPainter *painter, const QStyleOptionVi
   if ( cg == QPalette::Normal && !(option.state & QStyle::State_Active) )
     cg = QPalette::Inactive;
 
-  if ( option.state & QStyle::State_Selected ) {
-    painter->fillRect( option.rect, option.palette.brush( cg, QPalette::Highlight ) );
-    painter->setPen( option.palette.color( cg, QPalette::HighlightedText ) );
-  } else {
-    painter->setPen(option.palette.color( cg, QPalette::Text ) );
-  }
+  QStyleOptionViewItemV4 opt(option);
+  opt.showDecorationSelected = true;
+  QApplication::style()->drawPrimitive( QStyle::PE_PanelItemViewItem, &opt, painter );
 
   painter->save();
   painter->translate( option.rect.topLeft() );
@@ -292,4 +327,6 @@ void AgentInstanceWidgetDelegate::drawFocus( QPainter *painter, const QStyleOpti
   }
 }
 
+}
+
 #include "agentinstancewidget.moc"
