@@ -758,10 +758,23 @@ class StandardActionManager::Private
         return;
 
       foreach( const Collection &collection, collections ) {
+        if ( !testAndSetOnlineResources(collection) )
+          break;
         AgentManager::self()->synchronizeCollection( collection, false );
       }
     }
 
+    bool testAndSetOnlineResources(const Akonadi::Collection& collection)
+    {
+      Akonadi::AgentInstance instance = Akonadi::AgentManager::self()->instance( collection.resource() );
+      if ( !instance.isOnline() ) {
+        if ( KMessageBox::questionYesNo( parentWidget, i18n( "Before to sync folder \"%1\" it's necessary to have resource online. Do you want to make it online?" , collection.name()  ), i18n( "Account \"%1\" is offline", instance.name() ) ) != KMessageBox::Yes )
+          return false;
+        instance.setIsOnline( true );
+      }
+      return true;
+    }
+
     void slotSynchronizeCollectionRecursive()
     {
       Q_ASSERT( collectionSelectionModel );
@@ -774,6 +787,8 @@ class StandardActionManager::Private
         return;
 
       foreach( const Collection &collection, collections ) {
+        if ( !testAndSetOnlineResources(collection) )
+          break;
         AgentManager::self()->synchronizeCollection( collection, true );
       }
     }
